@@ -16,12 +16,7 @@ private Q_SLOTS:
     {
         account = new MockAccount();
         AccountManager::instance().addAccount(account, false);
-        AccountManager::instance().selectAccount(account);
-    }
-
-    void cleanupTestCase()
-    {
-        AccountManager::instance().removeAccount(account);
+        AccountManager::instance().selectAccount(account, false);
     }
 
     void loadDataTest()
