@@ -48,6 +48,10 @@
 #include "autotests/mockaccount.h"
 #endif
 
+#if __has_include("KCrash")
+#include <KCrash>
+#endif
+
 using namespace Qt::Literals::StringLiterals;
 
 void setupUnifiedPush()
@@ -129,6 +133,10 @@ int main(int argc, char *argv[])
     KAboutData::setApplicationData(about);
     QGuiApplication::setWindowIcon(QIcon::fromTheme(QStringLiteral("org.kde.tokodon")));
 
+#if __has_include("KCrash")
+    KCrash::initialize();
+#endif
+
     QCommandLineParser parser;
     parser.setApplicationDescription(i18n("Client for decentralized social networks like Mastodon"));
     parser.addPositionalArgument(QStringLiteral("urls"), i18n("Supports https and web+ap url scheme"));
@@ -207,7 +215,7 @@ int main(int argc, char *argv[])
                 auto args = arguments;
                 args.removeFirst();
 
-                if (arguments.length() >= 1) {
+                if (!args.empty()) {
                     if (args[0].startsWith("web+ap"_L1)) {
                         NetworkController::instance().openWebApLink(args[0]);
                     } else if (args[0].startsWith("tokodon"_L1)) {
