@@ -8,6 +8,9 @@
 
 #include "utils/customemoji.h"
 
+class QQuickTextDocument;
+class QQuickItem;
+
 /**
  * @brief Handles some miscellaneous text processing tasks.
  */
@@ -44,4 +47,26 @@ public:
      * @return HTML to be used as rich text.
      */
     static QString replaceCustomEmojis(const QList<CustomEmoji> &emojis, const QString &source);
+
+    /**
+     * @brief Determines whether or not a URL could possibly be a post.
+     * @note This isn't supposed to be perfect, but catch the 99% case.
+     */
+    static bool isPostUrl(const QString &url);
+
+    /**
+     * @brief Workaround for QTBUG 93281.
+     * @note Only has an effect on Qt <6.7.
+     */
+    Q_INVOKABLE void forceRefreshTextDocument(QQuickTextDocument *textDocument, QQuickItem *item);
 };
+
+namespace TextRegex
+{
+static const QRegularExpression
+    url(QStringLiteral(R"(\b((www\.(?!\.)(?!(\w|\.|-)+@)|https?:(//)?\w)(&(?![lg]t;)|[^&\s<>'"])+(&(?![lg]t;)|[^&!,.\s<>'"\]):])))"),
+        QRegularExpression::CaseInsensitiveOption | QRegularExpression::UseUnicodePropertiesOption);
+static const QRegularExpression hashtagExp(QStringLiteral("(?:<a\\b[^>]*>#<span>(\\S*)<\\/span><\\/a>)"));
+static const QRegularExpression extraneousParagraphExp(QStringLiteral("(\\s*(?:<(?:p|br)\\s*\\/?>)+\\s*<\\/p>)"));
+static const QRegularExpression extraneousBreakExp(QStringLiteral("(\\s*(?:<br\\s*\\/?>)+\\s*)<\\/p>"));
+}
